/*									tab:4
 *
 *
 * "Copyright (c) 2000-2002 The Regents of the University  of California.
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice, the following
 * two paragraphs and the author appear in all copies of this software.
 *
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY FOR
 * DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT
 * OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF
 * CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND THE UNIVERSITY OF CALIFORNIA HAS NO OBLIGATION TO
 * PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS."
 *
 */
/*									tab:4
 *  IMPORTANT: READ BEFORE DOWNLOADING, COPYING, INSTALLING OR USING.  By
 *  downloading, copying, installing or using the software you agree to
 *  this license.  If you do not agree to this license, do not download,
 *  install, copy or use the software.
 *
 *  Intel Open Source License
 *
 *  Copyright (c) 2002 Intel Corporation
 *  All rights reserved.
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *
 *	Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *	Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *      Neither the name of the Intel Corporation nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 *  PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE INTEL OR ITS
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *  LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *
 */
/*
 *
 * Authors:             Jason Hill, Philip Levis, Nelson Lee, David Gay
 *
 * Modified for the Chipcon CC1010 / 8051-based motes by David Patnode
 *
 */

#ifndef TOSH_HARDWARE_H
#define TOSH_HARDWARE_H

#include <keilhardware.h>
#include <wisenet_hardware.h>
/* 
 * #include <sensorboard.h>
 * This needs to be included at the end of this file, after the pin assignments
 *
 */

/* Defined by sensorboard.h now
TOSH_ASSIGN_PIN(RED_LED, 1, 2);
TOSH_ASSIGN_PIN(YELLOW_LED, 1, 3);
TOSH_ASSIGN_PIN(GREEN_LED, 1, 4);
TOSH_ASSIGN_PIN(BLUE_LED, 2, 5);
*/

// Assign all general IO ports
TOSH_ASSIGN_PIN(P0_0, 0, 0);
TOSH_ASSIGN_PIN(P0_1, 0, 1);
TOSH_ASSIGN_PIN(P0_2, 0, 2);
TOSH_ASSIGN_PIN(P0_3, 0, 3);
TOSH_ASSIGN_PIN(P1_0, 1, 0);
TOSH_ASSIGN_PIN(P1_1, 1, 1);
TOSH_ASSIGN_PIN(P1_2, 1, 2);
TOSH_ASSIGN_PIN(P1_3, 1, 3);
TOSH_ASSIGN_PIN(P1_4, 1, 4);
TOSH_ASSIGN_PIN(P1_5, 1, 5);
TOSH_ASSIGN_PIN(P1_6, 1, 6);
TOSH_ASSIGN_PIN(P1_7, 1, 7);
TOSH_ASSIGN_PIN(P2_0, 2, 0);
TOSH_ASSIGN_PIN(P2_1, 2, 1);
TOSH_ASSIGN_PIN(P2_2, 2, 2);
TOSH_ASSIGN_PIN(P2_3, 2, 3);
TOSH_ASSIGN_PIN(P2_4, 2, 4);
TOSH_ASSIGN_PIN(P2_5, 2, 5);
TOSH_ASSIGN_PIN(P2_6, 2, 6);
TOSH_ASSIGN_PIN(P2_7, 2, 7);
TOSH_ASSIGN_PIN(P3_0, 3, 0);
TOSH_ASSIGN_PIN(P3_1, 3, 1);
TOSH_ASSIGN_PIN(P3_2, 3, 2);
TOSH_ASSIGN_PIN(P3_3, 3, 3);
TOSH_ASSIGN_PIN(P3_4, 3, 4);
TOSH_ASSIGN_PIN(P3_5, 3, 5);
TOSH_ASSIGN_PIN(P3_6, 3, 6);
TOSH_ASSIGN_PIN(P3_7, 3, 7);

// Assign special function IO pins
TOSH_ASSIGN_PIN(INT0, 3, 2);
TOSH_ASSIGN_PIN(INT1, 3, 3);

TOSH_ASSIGN_PIN(UART_RXD0, 3, 0);
TOSH_ASSIGN_PIN(UART_TXD0, 3, 1);

TOSH_ASSIGN_PIN(UART_RXD1, 2, 0);
TOSH_ASSIGN_PIN(UART_TXD1, 2, 1);

TOSH_ASSIGN_PIN(TIMER0_COUNT, 3, 4);
TOSH_ASSIGN_PIN(TIMER1_COUNT, 3, 5);

TOSH_ASSIGN_OUTPUT_ONLY_PIN(PWM2, 3, 4);
TOSH_ASSIGN_OUTPUT_ONLY_PIN(PWM3, 3, 5);

TOSH_ASSIGN_PIN(SPI_SCK, 0, 0);
TOSH_ASSIGN_PIN(SPI_MOSI, 0, 1);
TOSH_ASSIGN_PIN(SPI_MISO, 0, 2);

/* Now include sensorboard.h which defines the LED pins & others */
#include <sensorboard.h>


void TOSH_SET_PIN_DIRECTIONS(void)
{
// Set ports to input to minimize power usage
  halSetPortDir(0, PIN);
  halSetPortDir(1, PIN);
  halSetPortDir(2, PIN);
  halSetPortDir(3, PIN);

  TOSH_MAKE_RED_LED_OUTPUT();
  TOSH_MAKE_YELLOW_LED_OUTPUT();
  TOSH_MAKE_GREEN_LED_OUTPUT();
//  TOSH_MAKE_BLUE_LED_OUTPUT();

// TOSH_MAKE_PWM2_OUTPUT();
// TOSH_MAKE_PWM3_OUTPUT();

//  TOSH_CLR_RED_LED_PIN();
//  TOSH_CLR_YELLOW_LED_PIN();
//  TOSH_CLR_GREEN_LED_PIN();
//  TOSH_CLR_BLUE_LED_PIN();

//  TOSH_MAKE_ONE_WIRE_INPUT();
//  TOSH_SET_ONE_WIRE_PIN();
}


#endif //TOSH_HARDWARE_H
