/*									tab:4
 * Copyright (c) 2002 the University of Southern California.
 * All rights reserved.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose, without fee, and without written agreement is
 * hereby granted, provided that the above copyright notice and the following
 * two paragraphs appear in all copies of this software.
 *
 * IN NO EVENT SHALL THE UNIVERSITY OF SOUTHERN CALIFORNIA BE LIABLE TO ANY
 * PARTY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES
 * ARISING OUT OF THE USE OF THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE
 * UNIVERSITY OF SOUTHERN CALIFORNIA HAS BEEN ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * THE UNIVERSITY OF SOUTHERN CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE PROVIDED HEREUNDER IS
 * ON AN "AS IS" BASIS, AND THE UNIVERSITY OF SOUTHERN CALIFORNIA HAS NO
 * OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
 * MODIFICATIONS.
 *
 * Authors:	Wei Ye
 * 
 * UART debugging: this component is for sending debugging bytes thru UART
 *   Note: can't be used with any application that uses the UART, e.g. motenic
 *
 * Modified for use with the CC1010 UART 0 by David Patnode
 * 
 * 
 */

#ifndef UART_DEBUG
#define UART_DEBUG

#ifdef SMAC_DEBUG

#define DEBUG_BUF_LEN 255
#define ADVANCE(x) x = (((x+1) >= DEBUG_BUF_LEN) ? 0 : x+1)  // from TXMAN.c
#define UART_IDLE 0
#define UART_BUSY 1
#define BAUD_RATE 57600

// variables for UART debugging
char UARTState;
char debugBuf[DEBUG_BUF_LEN];
uint8_t debugHead;
uint8_t debugTail;
uint8_t debugBufCount;


void uartDebug_init()
{
   UARTState = UART_IDLE;
   debugBufCount = 0;
   debugHead = 0;
   debugTail = 0;
   // initialize UART 0
   UART0_SETUP(BAUD_RATE, CLK_FREQ, UART_NO_PARITY | UART_TX_ONLY | UART_ISR);
//   TOSH_SET_UART_RXD0_PIN();
   INT_ENABLE(INUM_UART0,INT_ON);
   // suppose global interrupt is enabled
}


void uartDebug_txByte(char data_byte)
{
   bool prev = TOSH_interrupt_disable();
   if (UARTState == UART_IDLE) { // send byte if UART is idle 
      UARTState = UART_BUSY;
      if(prev) {
      	TOSH_interrupt_enable();
      }
      // send byte to UART
	  UART0_SEND(data_byte);
   } else {  // UART is busy, put byte into buffer
      // if buffer is full, the byte will be dropped silently
      if (debugBufCount < DEBUG_BUF_LEN) {
         debugBuf[debugTail] = data_byte;
         ADVANCE(debugTail);
         debugBufCount++;
      }
      if(prev) {
      	TOSH_interrupt_enable();
      }
   }
}


TOSH_INTERRUPT(int_UART0, INUM_UART0) {
   // UART is able to send next byte
   // This interrupt handler is using the INTERRUPT macro, in which 
   // the global interrupt is enabled, so the interrupt handler can
   // be interruptted too.
   char data_byte;

   INT_GLOBAL_ENABLE(INT_OFF);			// Disable global interrupts
   INT_SETFLAG(INUM_UART0_TX, INT_CLR);		// Clear the interrupt flag
	P2_5 = !P2_5;

   if(debugBufCount > 0) {
      INT_GLOBAL_ENABLE(INT_ON);			// Enable global interrupts
      data_byte = debugBuf[debugHead];
      ADVANCE(debugHead);
      debugBufCount--;
      // send next byte to UART
 	  UART0_SEND(data_byte);
   } else {
      UARTState = UART_IDLE;
      INT_GLOBAL_ENABLE(INT_ON);			// Enable global interrupts
   }
}


#else
// UART_DEBUG_ENABLE is not defined

static inline void uartDebug_init() { }
static inline void uartDebug_txByte(char data_byte) { }

#endif  // UART_DEBUG_ENABLE

#endif  // UART_DEBUG

